| Title: | RNA-Seq multi-mapping Reads Quantification Tool |
|---|---|
| Description: | RNA-Seq is currently used routinely, and it provides accurate information on gene transcription. However, the method cannot accurately estimate duplicated genes expression. Several strategies have been previously used, but all of them provide biased results. With Rmmquant, if a read maps at different positions, the tool detects that the corresponding genes are duplicated; it merges the genes and creates a merged gene. The counts of ambiguous reads is then based on the input genes and the merged genes. Rmmquant is a drop-in replacement of the widely used tools findOverlaps and featureCounts that handles multi-mapping reads in an unabiased way. |
| Authors: | Zytnicki Matthias [aut, cre] |
| Maintainer: | Zytnicki Matthias <[email protected]> |
| License: | GPL-3 |
| Version: | 1.31.0 |
| Built: | 2026-05-30 06:58:36 UTC |
| Source: | https://github.com/bioc/Rmmquant |
RmmquantClass object.Get the counts table of an RmmquantClass object.
counts(object) ## S4 method for signature 'RmmquantClass' counts(object)counts(object) ## S4 method for signature 'RmmquantClass' counts(object)
object |
An |
The count matrix, in a SummarizedExperiment
example <- RmmquantClassExample() counts(example)example <- RmmquantClassExample() counts(example)
Counts the number of reads per gene.
Matthias Zytnicki, [email protected]
An S4 class for Rmmquant.
annotationFileThe annotation file
readsFilesThe reads files
genomicRangesThe annotation, in a
GenomicRanges format.
genomicRangesListThe annotation, in a
GenomicRangesList format.
sampleNamesThe name of the samples
overlapThe minimum number of overlapping base pairs to declare a match.
strandsWhether annotation of the same strand should be considered.
sortsWhether the files are sorted.
countThresholdThe reads files
mergeThresholdThe reads files
printGeneNameWhether the (vernacular) gene name is reported.
quietShut Rmmquant up.
progressPrint the progress of the tool.
nThreadsThe number of threads.
formatsThe format of the reads files (SAM or BAM).
nOverlapDiffDifference of overlap between a primary map and a secondary map.
pcOverlapDiffRatio of overlap between a primary map and a secondary map.
countsA SummarizedExperiment storing the counts.
Example of Rmmquant constructor.
RmmquantClassExample()RmmquantClassExample()
An RmmquantClass.
example <- RmmquantExample()example <- RmmquantExample()
Example of Rmmquant use
RmmquantExample()RmmquantExample()
An SummarizedExperiement.
example <- RmmquantExample()example <- RmmquantExample()
Main Rmmquant function.
RmmquantRun( annotationFile = "", readsFiles = character(0), genomicRanges = GRanges(), genomicRangesList = GRangesList(), sampleNames = character(0), overlap = NA_integer_, strands = character(0), sorts = logical(0), countThreshold = NA_integer_, mergeThreshold = NA_real_, printGeneName = FALSE, quiet = TRUE, progress = FALSE, nThreads = 1, formats = character(0), nOverlapDiff = NA_integer_, pcOverlapDiff = NA_real_, lazyload = FALSE )RmmquantRun( annotationFile = "", readsFiles = character(0), genomicRanges = GRanges(), genomicRangesList = GRangesList(), sampleNames = character(0), overlap = NA_integer_, strands = character(0), sorts = logical(0), countThreshold = NA_integer_, mergeThreshold = NA_real_, printGeneName = FALSE, quiet = TRUE, progress = FALSE, nThreads = 1, formats = character(0), nOverlapDiff = NA_integer_, pcOverlapDiff = NA_real_, lazyload = FALSE )
annotationFile |
The annotation file |
readsFiles |
The reads files |
genomicRanges |
The annotation, in a
|
genomicRangesList |
The annotation, in a
|
sampleNames |
The name of the samples |
overlap |
The minimum number of overlapping base pairs to declare a match. |
strands |
Whether annotation of the same strand should be considered. |
sorts |
Whether the files are sorted. |
countThreshold |
The reads files |
mergeThreshold |
The reads files |
printGeneName |
Whether the (vernacular) gene name is reported. |
quiet |
Shut Rmmquant up. |
progress |
Print the progress of the tool. |
nThreads |
The number of threads. |
formats |
The format of the reads files (SAM or BAM). |
nOverlapDiff |
Difference of overlap between a primary map and a secondary map. |
pcOverlapDiff |
Ratio of overlap between a primary map and a secondary map. |
lazyload |
Usual for S4 functions. |
A SummerizedExperiment.
dir <- system.file("extdata", package="Rmmquant", mustWork = TRUE) gtfFile <- file.path(dir, "test.gtf") samFile <- file.path(dir, "test.sam") table <- RmmquantRun(gtfFile, samFile)dir <- system.file("extdata", package="Rmmquant", mustWork = TRUE) gtfFile <- file.path(dir, "test.gtf") samFile <- file.path(dir, "test.sam") table <- RmmquantRun(gtfFile, samFile)
RmmquantClass object.Show the content of an RmmquantClass object.
## S4 method for signature 'RmmquantClass' show(object)## S4 method for signature 'RmmquantClass' show(object)
object |
An |
A description of the object.
example <- RmmquantClassExample() exampleexample <- RmmquantClassExample() example
Rmmquant object validation function.
validateRmmquant(object)validateRmmquant(object)
object |
A |
TRUE, if succeed, otherwise a character.